@@ -1,7 +1,7 @@
 from os.path import join, split
 
 TEST = False
-FAKE = True
+FAKE = False
 
 DEBUG = True
 FULLSCREEN = True
